DDM_with_confidence_slow_fullconfRT: DDM trials generation with multiple post-decision...

View source: R/RcppExports.R

DDM_with_confidence_slow_fullconfRTR Documentation

DDM trials generation with multiple post-decision accumulation time

Description

This function generates trials using the Drift Diffusion Model. Additional evidence is accumulated for a fixed time after the decision boundary has been reached. Note: here, decision boundaries are a and -a and starting point is equal to a*z.

Usage

DDM_with_confidence_slow_fullconfRT(
  v,
  a,
  ter,
  z,
  ntrials,
  s,
  dt,
  t2distribution,
  postdriftmod
)

Arguments

v

Drift rate

a

Decision boundary, evidence at t = 0 is equal to a*z. Decision boundaries are a and -a

ter

Non-decision time

z

Starting point bias in evidence. For unbiased DDM, use z = 0

ntrials

Number of DDM trials to generate. Must be a multiple of length(t2time) so that all confidence RT trials are repeated the same number of times

s

Scaling parameter

dt

Time step size

t2distribution

Vector containing the whole confidence RT distribution

postdriftmod

V-ratio. If equal to 1, post-decision drift rate is equal to decision drift rate


pledenmat/myPackage documentation built on July 25, 2022, 3:50 p.m.