add: This is my addition function

Description Usage Arguments Value Examples

View source: R/add.R

Description

This function generates and returns the sum of x and y.

Usage

1
add(x, y)

Arguments

x

This is the first value to add.

y

This is the second value to add.

Value

This function returns the sum of x and y.

Examples

1
2
3
4
5
### First, you can add small numbers. 
add(1,1)

### You can also add big numbers.
add(500, 4093)

Aubreyodom/mypackage documentation built on May 29, 2019, midnight