fars_map_state: Accidents by state and year

Description Usage Arguments Value

View source: R/fars_functions.R

Description

A funcion to make a plot with a state map showing the accidents location by year If the state.num is invalid the function shows an error

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

An Integer with the State Code

year

A string, or an integer, with the input year

Value

A plot showing a state map with the accidents location by year

fars_map_state(49, 2015)


cregexp/MyPackage documentation built on Nov. 4, 2019, 9:17 a.m.