Description Usage Arguments Value Examples
View source: R/fars_functions.R
This function selects data taking into account the month
1 | fars_read_years(years)
|
years |
A vector with a list of years |
A data.frame including entries in data by month, or NULL if the year is not valid
1 | fars_read_years(2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.