Description Usage Arguments Value Examples
View source: R/fars_functions.R
This function summarizes yearly accidents, by month
1 | fars_summarize_years(years)
|
years |
A vector with a list of years to summarize |
A data.frame with number of accidents by years summarized by month
1 | fars_summarize_years(c(2015, 2014))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.