make_filename: Make file name This funciotn makes .csv data file name taking...

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

Make file name This funciotn makes .csv data file name taking into account the given.

Usage

1

Arguments

year

An integer with the input

Value

This function returns a string with the data file name for a given year, and the file path within the package.

Examples

1

cregexp/MyPackage documentation built on Nov. 4, 2019, 9:17 a.m.