subtract: Subtraction Function

Description Usage Arguments Value Examples

View source: R/add.R

Description

This function generates and returns the difference of x and y.

Usage

1
subtract(x, y)

Arguments

x

This is the value from which we want to subtract.

y

This is the value we will subtract.

Value

This function returns the difference of x and y.

Examples

1
2
3
4
5
### First, you can subtract small numbers. 
subtract(1,1)

### You can also subtract big numbers.
subtract(500, 4093)

Aubreyodom/mypackage documentation built on May 29, 2019, midnight