Description Usage Arguments Value Examples
This function generates and returns the sum of x and y.
1 | add(x, y)
|
x |
This is the first value to add. |
y |
This is the second value to add. |
This function returns the sum of x and y.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.