Description Usage Arguments Value
View source: R/fars_functions.R
A funcion to make a plot with a state map showing the accidents location by year If the state.num is invalid the function shows an error
1 | fars_map_state(state.num, year)
|
state.num |
An Integer with the State Code |
year |
A string, or an integer, with the input year |
A plot showing a state map with the accidents location by year
fars_map_state(49, 2015)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.