Description Usage Arguments Details Value Examples
View source: R/fars_functions.R
This function reads data from .csv file from the US National Highway Traffic Safety Administration's Fatality Analysis Reporting System (FARS), which is a nationwide census, providing the American public yearly data, regarding fatal injuries suffered in motor vehicle traffic crashes.
1 | fars_read(filename)
|
filename |
A character string with the name of the file to read |
For more information, see: \itemhttps://www.nhtsa.gov/Data/Fatality-Analysis-Reporting-System-(FARS)
A data frame with data readed from the csv file, or an error if the file does not exists.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.