Description Usage Arguments Value Examples
View source: R/fars_functions.R
Make file name This funciotn makes .csv data file name taking into account the given.
1 | make_filename(year)
|
year |
An integer with the input |
This function returns a string with the data file name for a given year, and the file path within the package.
1 | make_filename(2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.