Description Usage Arguments Value Examples
This function generates and returns the difference of x and y.
1 | subtract(x, y)
|
x |
This is the value from which we want to subtract. |
y |
This is the value we will subtract. |
This function returns the difference of x and y.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.